###########################################################
#
# scanbuttond
#
###########################################################

# It is usually "zcat" (for .gz) or "bzcat" (for .bz2)
#
# If you list yourself as MAINTAINER, please give a valid email
# address, and indicate your irc nick if it cannot be easily deduced
# from your name or email address.  If you leave MAINTAINER set to
# "NSLU2 Linux" other developers will feel free to edit.
#
SCANBUTTOND_SITE=http://$(SOURCEFORGE_MIRROR)/sourceforge/scanbuttond
SCANBUTTOND_VERSION=0.2.3
SCANBUTTOND_SOURCE=scanbuttond-$(SCANBUTTOND_VERSION).tar.gz
SCANBUTTOND_DIR=scanbuttond-$(SCANBUTTOND_VERSION)
SCANBUTTOND_UNZIP=zcat
SCANBUTTOND_MAINTAINER=Karl H. Beckers <karl.h.beckers@gmx.net>
SCANBUTTOND_DESCRIPTION=A scanner button daemon for Linux
SCANBUTTOND_SECTION=extras
SCANBUTTOND_PRIORITY=optional
SCANBUTTOND_DEPENDS=
SCANBUTTOND_SUGGESTS=
SCANBUTTOND_CONFLICTS=

#
# SCANBUTTOND_IPK_VERSION should be incremented when the ipk changes.
#
SCANBUTTOND_IPK_VERSION=1

#
# SCANBUTTOND_CONFFILES should be a list of user-editable files
#SCANBUTTOND_CONFFILES=/opt/etc/scanbuttond.conf /opt/etc/init.d/SXXscanbuttond

#
# SCANBUTTOND_PATCHES should list any patches, in the the order in
# which they should be applied to the source code.
#
#SCANBUTTOND_PATCHES=$(SCANBUTTOND_SOURCE_DIR)/scanbutton.patch1 $(SCANBUTTOND_SOURCE_DIR)/scanbutton.patch2

#
# If the compilation of the package requires additional
# compilation or linking flags, then list them here.
#
SCANBUTTOND_CPPFLAGS=
SCANBUTTOND_LDFLAGS=

#
# SCANBUTTOND_BUILD_DIR is the directory in which the build is done.
# SCANBUTTOND_SOURCE_DIR is the directory which holds all the
# patches and ipkg control files.
# SCANBUTTOND_IPK_DIR is the directory in which the ipk is built.
# SCANBUTTOND_IPK is the name of the resulting ipk files.
#
# You should not change any of these variables.
#
SCANBUTTOND_BUILD_DIR=$(BUILD_DIR)/scanbuttond
SCANBUTTOND_SOURCE_DIR=$(SOURCE_DIR)/scanbuttond
SCANBUTTOND_IPK_DIR=$(BUILD_DIR)/scanbuttond-$(SCANBUTTOND_VERSION)-ipk
SCANBUTTOND_IPK=$(BUILD_DIR)/scanbuttond_$(SCANBUTTOND_VERSION)-$(SCANBUTTOND_IPK_VERSION)_$(TARGET_ARCH).ipk

.PHONY: scanbuttond-source scanbuttond-unpack scanbuttond scanbuttond-stage scanbuttond-ipk scanbuttond-clean scanbuttond-dirclean scanbuttond-check

#
# This is the dependency on the source code.  If the source is missing,
# then it will be fetched from the site using wget.
#
$(DL_DIR)/$(SCANBUTTOND_SOURCE):
	$(WGET) -P $(DL_DIR) $(SCANBUTTOND_SITE)/$(@F) || \
	$(WGET) -P $(DL_DIR) $(SOURCES_NLO_SITE)/$(@F)

#
# The source code depends on it existing within the download directory.
# This target will be called by the top level Makefile to download the
# source code's archive (.tar.gz, .bz2, etc.)
#
scanbuttond-source: $(DL_DIR)/$(SCANBUTTOND_SOURCE) $(SCANBUTTOND_PATCHES)

#
# This target unpacks the source code in the build directory.
# If the source archive is not .tar.gz or .tar.bz2, then you will need
# to change the commands here.  Patches to the source code are also
# applied in this target as required.
#
# This target also configures the build within the build directory.
# Flags such as LDFLAGS and CPPFLAGS should be passed into configure
# and NOT $(MAKE) below.  Passing it to configure causes configure to
# correctly BUILD the Makefile with the right paths, where passing it
# to Make causes it to override the default search paths of the compiler.
#
# If the compilation of the package requires other packages to be staged
# first, then do that first (e.g. "$(MAKE) <bar>-stage <baz>-stage").
#
# If the package uses  GNU libtool, you should invoke $(PATCH_LIBTOOL) as
# shown below to make various patches to it.
#
#	$(MAKE) <bar>-stage <baz>-stage
$(SCANBUTTOND_BUILD_DIR)/.configured: $(DL_DIR)/$(SCANBUTTOND_SOURCE) $(SCANBUTTOND_PATCHES) make/scanbuttond.mk
	rm -rf $(BUILD_DIR)/$(SCANBUTTOND_DIR) $(@D)
	$(SCANBUTTOND_UNZIP) $(DL_DIR)/$(SCANBUTTOND_SOURCE) | tar -C $(BUILD_DIR) -xvf -
	if test -n "$(SCANBUTTOND_PATCHES)" ; \
		then cat $(SCANBUTTOND_PATCHES) | \
		patch -d $(BUILD_DIR)/$(SCANBUTTOND_DIR) -p0 ; \
	fi
	if test "$(BUILD_DIR)/$(SCANBUTTOND_DIR)" != "$(@D)" ; \
		then mv $(BUILD_DIR)/$(SCANBUTTOND_DIR) $(@D) ; \
	fi
	(cd $(@D); \
		$(TARGET_CONFIGURE_OPTS) \
		CPPFLAGS="$(STAGING_CPPFLAGS) $(SCANBUTTOND_CPPFLAGS)" \
		LDFLAGS="$(STAGING_LDFLAGS) $(SCANBUTTOND_LDFLAGS)" \
		./configure \
		--build=$(GNU_HOST_NAME) \
		--host=$(GNU_TARGET_NAME) \
		--target=$(GNU_TARGET_NAME) \
		--prefix=/opt \
		--disable-nls \
		--disable-static \
	)
	$(PATCH_LIBTOOL) $(@D)/libtool
	touch $@

scanbuttond-unpack: $(SCANBUTTOND_BUILD_DIR)/.configured

#
# This builds the actual binary.
#
$(SCANBUTTOND_BUILD_DIR)/.built: $(SCANBUTTOND_BUILD_DIR)/.configured
	rm -f $@
	$(MAKE) -C $(@D)
	touch $@

#
# This is the build convenience target.
#
scanbuttond: $(SCANBUTTOND_BUILD_DIR)/.built

#
# If you are building a library, then you need to stage it too.
#
$(SCANBUTTOND_BUILD_DIR)/.staged: $(SCANBUTTOND_BUILD_DIR)/.built
	rm -f $@
	$(MAKE) -C $(@D) DESTDIR=$(STAGING_DIR) install
	touch $@

scanbuttond-stage: $(SCANBUTTOND_BUILD_DIR)/.staged

#
# This rule creates a control file for ipkg.  It is no longer
# necessary to create a seperate control file under sources/scanbuttond
#
$(SCANBUTTOND_IPK_DIR)/CONTROL/control:
	@install -d $(@D)
	@rm -f $@
	@echo "Package: scanbuttond" >>$@
	@echo "Architecture: $(TARGET_ARCH)" >>$@
	@echo "Priority: $(SCANBUTTOND_PRIORITY)" >>$@
	@echo "Section: $(SCANBUTTOND_SECTION)" >>$@
	@echo "Version: $(SCANBUTTOND_VERSION)-$(SCANBUTTOND_IPK_VERSION)" >>$@
	@echo "Maintainer: $(SCANBUTTOND_MAINTAINER)" >>$@
	@echo "Source: $(SCANBUTTOND_SITE)/$(SCANBUTTOND_SOURCE)" >>$@
	@echo "Description: $(SCANBUTTOND_DESCRIPTION)" >>$@
	@echo "Depends: $(SCANBUTTOND_DEPENDS)" >>$@
	@echo "Suggests: $(SCANBUTTOND_SUGGESTS)" >>$@
	@echo "Conflicts: $(SCANBUTTOND_CONFLICTS)" >>$@

#
# This builds the IPK file.
#
# Binaries should be installed into $(SCANBUTTOND_IPK_DIR)/opt/sbin or $(SCANBUTTOND_IPK_DIR)/opt/bin
# (use the location in a well-known Linux distro as a guide for choosing sbin or bin).
# Libraries and include files should be installed into $(SCANBUTTOND_IPK_DIR)/opt/{lib,include}
# Configuration files should be installed in $(SCANBUTTOND_IPK_DIR)/opt/etc/scanbuttond/...
# Documentation files should be installed in $(SCANBUTTOND_IPK_DIR)/opt/doc/scanbuttond/...
# Daemon startup scripts should be installed in $(SCANBUTTOND_IPK_DIR)/opt/etc/init.d/S??scanbuttond
#
# You may need to patch your application to make it use these locations.
#
$(SCANBUTTOND_IPK): $(SCANBUTTOND_BUILD_DIR)/.built
	rm -rf $(SCANBUTTOND_IPK_DIR) $(BUILD_DIR)/scanbuttond_*_$(TARGET_ARCH).ipk
	$(MAKE) -C $(SCANBUTTOND_BUILD_DIR) DESTDIR=$(SCANBUTTOND_IPK_DIR) install-strip
#	install -d $(SCANBUTTOND_IPK_DIR)/opt/etc/
#	install -m 644 $(SCANBUTTOND_SOURCE_DIR)/scanbuttond.conf $(SCANBUTTOND_IPK_DIR)/opt/etc/scanbuttond.conf
#	install -d $(SCANBUTTOND_IPK_DIR)/opt/etc/init.d
#	install -m 755 $(SCANBUTTOND_SOURCE_DIR)/rc.scanbuttond $(SCANBUTTOND_IPK_DIR)/opt/etc/init.d/SXXscanbuttond
#	sed -i -e '/^#!/aOPTWARE_TARGET=${OPTWARE_TARGET}' $(SCANBUTTOND_IPK_DIR)/opt/etc/init.d/SXXscanbuttond
	$(MAKE) $(SCANBUTTOND_IPK_DIR)/CONTROL/control
#	install -m 755 $(SCANBUTTOND_SOURCE_DIR)/postinst $(SCANBUTTOND_IPK_DIR)/CONTROL/postinst
#	sed -i -e '/^#!/aOPTWARE_TARGET=${OPTWARE_TARGET}' $(SCANBUTTOND_IPK_DIR)/CONTROL/postinst
#	install -m 755 $(SCANBUTTOND_SOURCE_DIR)/prerm $(SCANBUTTOND_IPK_DIR)/CONTROL/prerm
#	sed -i -e '/^#!/aOPTWARE_TARGET=${OPTWARE_TARGET}' $(SCANBUTTOND_IPK_DIR)/CONTROL/prerm
#	if test -n "$(UPD-ALT_PREFIX)"; then \
		sed -i -e '/^[ 	]*update-alternatives /s|update-alternatives|$(UPD-ALT_PREFIX)/bin/&|' \
			$(SCANBUTTOND_IPK_DIR)/CONTROL/postinst $(SCANBUTTOND_IPK_DIR)/CONTROL/prerm; \
	fi
	echo $(SCANBUTTOND_CONFFILES) | sed -e 's/ /\n/g' > $(SCANBUTTOND_IPK_DIR)/CONTROL/conffiles
	cd $(BUILD_DIR); $(IPKG_BUILD) $(SCANBUTTOND_IPK_DIR)

#
# This is called from the top level makefile to create the IPK file.
#
scanbuttond-ipk: $(SCANBUTTOND_IPK)

#
# This is called from the top level makefile to clean all of the built files.
#
scanbuttond-clean:
	rm -f $(SCANBUTTOND_BUILD_DIR)/.built
	-$(MAKE) -C $(SCANBUTTOND_BUILD_DIR) clean

#
# This is called from the top level makefile to clean all dynamically created
# directories.
#
scanbuttond-dirclean:
	rm -rf $(BUILD_DIR)/$(SCANBUTTOND_DIR) $(SCANBUTTOND_BUILD_DIR) $(SCANBUTTOND_IPK_DIR) $(SCANBUTTOND_IPK)
#
#
# Some sanity check for the package.
#
scanbuttond-check: $(SCANBUTTOND_IPK)
	perl scripts/optware-check-package.pl --target=$(OPTWARE_TARGET) $(SCANBUTTOND_IPK)
